==> beast-0.6.0.tar.gz: beast-0.6.0/bse/bsewaverepo.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsewaverepo.proc"

#include <bse/bseplugin.h>
#include <bse/bseprocedure.h>
#include <bse/bsewaverepo.h>
#include <bse/gslloader.h>
#include <bse/bsewave.h>

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <errno.h>


#line 30 "bsewaverepo.proc"

static BseErrorType
load_file (BseWaveRepo *wrepo,
	   const gchar *file_name,
           BseWave    **wave_p)
{
  GslErrorType error;
  GslWaveFileInfo *finfo;
  GslWaveDsc *wdsc;
  BseWave *wave;
  gchar *fname;
  guint i;

  *wave_p = NULL;
  finfo = gsl_wave_file_info_load (file_name, &error);
  if (!finfo)
    return error;
  if (finfo->n_waves != 1)
    {
      gsl_wave_file_info_unref (finfo);
      return BSE_ERROR_FORMAT_UNKNOWN;
    }
  
  wdsc = gsl_wave_dsc_load (finfo, 0, &error);
  gsl_wave_file_info_unref (finfo);
  if (!wdsc)
    return error;
  
  fname = g_path_get_basename (file_name);
  wave = g_object_new (BSE_TYPE_WAVE,
		       "uname", fname,
		       NULL);
  bse_wave_set_description_bits (wave, wdsc, TRUE);
  g_free (fname);
  for (i = 0; i < wdsc->n_chunks; i++)
    {
      GslWaveChunk *wchunk = gsl_wave_chunk_create (wdsc, i, error ? NULL : &error);
      
      if (wchunk)
        bse_wave_add_chunk (wave, wchunk);
    }
  bse_wave_set_locator (wave, file_name, wdsc->name);
  
  gsl_wave_dsc_free (wdsc);
  
  if (wave->n_wchunks)
    {
      bse_container_add_item (BSE_CONTAINER (wrepo), BSE_ITEM (wave));
      *wave_p = wave;
      error = GSL_ERROR_NONE;
    }
  else
    error = BSE_ERROR_WAVE_NOT_FOUND;
  g_object_unref (wave);
  
  return error;
}


#line 89 "bsewaverepo.proc"

#line 92 "bsewaverepo.proc"


/* --- load-file --- */
static void
load_file_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 94 "bsewaverepo.proc"
 {
#line 96 "bsewaverepo.proc"
  *(in_pspecs++)    = bse_param_spec_object ("wave_repo", "Wave Repo", NULL,
				 BSE_TYPE_WAVE_REPO, SFI_PARAM_STANDARD);
  *(in_pspecs++) = sfi_pspec_string ("file_name", "File Name", "The file to import waves from",
			    NULL, SFI_PARAM_STANDARD);
  *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", NULL,
				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
				SFI_PARAM_STANDARD);
}
#line 104 "bsewaverepo.proc"
 }
static BseErrorType
#line 104 "bsewaverepo.proc"
load_file_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 107 "bsewaverepo.proc"
{
#line 108 "bsewaverepo.proc"
  
  BseWaveRepo *self    = (BseWaveRepo*) bse_value_get_object (in_values++);
  gchar *file_name     = sfi_value_get_string (in_values++);
  BseUndoStack *ustack;
  BseErrorType error;
  BseWave *wave;
  
#line 115 "bsewaverepo.proc"
  
  if (!BSE_IS_WAVE_REPO (self) || !file_name)
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  ustack = bse_item_undo_open (self, "load-wave");
  error = load_file (self, file_name, &wave);
  if (wave)
    bse_item_push_undo_proc (self, "remove-wave", wave);
  bse_item_undo_close (ustack);
  
#line 125 "bsewaverepo.proc"
  
  g_value_set_enum (out_values++, error);
  
  return BSE_ERROR_NONE;
}

/* --- remove-wave --- */
static void
remove_wave_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 131 "bsewaverepo.proc"
 {
#line 133 "bsewaverepo.proc"
  *(in_pspecs++)    = bse_param_spec_object ("wave_repo", "Wave Repo", NULL,
				 BSE_TYPE_WAVE_REPO, SFI_PARAM_STANDARD);
  *(in_pspecs++)    = bse_param_spec_object ("wave", "Wave", NULL,
				 BSE_TYPE_WAVE, SFI_PARAM_STANDARD);
#line 137 "bsewaverepo.proc"
}  }
static BseErrorType
#line 137 "bsewaverepo.proc"
remove_wave_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 140 "bsewaverepo.proc"
{
#line 141 "bsewaverepo.proc"
  
  BseWaveRepo *self = (BseWaveRepo*) bse_value_get_object (in_values++);
  BseItem *child    = (BseItem*) bse_value_get_object (in_values++);
  BseUndoStack *ustack;

#line 146 "bsewaverepo.proc"
  
  if (!BSE_IS_WAVE_REPO (self) || !BSE_IS_WAVE (child) ||
      child->parent != BSE_ITEM (self))
    return BSE_ERROR_PROC_PARAM_INVAL;
  
#line 151 "bsewaverepo.proc"
  
  ustack = bse_item_undo_open (self, "remove-wave %s", bse_object_debug_name (child));
#line 153 "bsewaverepo.proc"
  
  bse_container_uncross_undoable (BSE_CONTAINER (self), child);
#line 155 "bsewaverepo.proc"
  
  bse_item_push_redo_proc (self, "remove-wave", child);
#line 157 "bsewaverepo.proc"
  
  bse_container_remove_backedup (BSE_CONTAINER (self), child, ustack);
#line 159 "bsewaverepo.proc"
  
  bse_item_undo_close (ustack);
  
  return BSE_ERROR_NONE;
}

/* --- bse-sample-file-info --- */
static void
bse_sample_file_info_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 165 "bsewaverepo.proc"
 {
#line 167 "bsewaverepo.proc"
  *(in_pspecs++) = sfi_pspec_string ("file_name", "File Name", "The file to load info from",
			    NULL, SFI_PARAM_STANDARD);
  *(out_pspecs++)   = bse_param_spec_boxed ("sample_file_info", NULL, NULL, BSE_TYPE_SAMPLE_FILE_INFO, SFI_PARAM_STANDARD);
}
#line 171 "bsewaverepo.proc"
 }
static BseErrorType
#line 171 "bsewaverepo.proc"
bse_sample_file_info_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 174 "bsewaverepo.proc"
{
#line 175 "bsewaverepo.proc"
  
  gchar *filename = sfi_value_get_string (in_values++);
  BseSampleFileInfo info = { 0, };
  GslWaveFileInfo *wfi = NULL;
  struct stat sbuf = { 0, };

#line 181 "bsewaverepo.proc"
  
  if (!filename)
    return BSE_ERROR_PROC_PARAM_INVAL;

#line 185 "bsewaverepo.proc"
  
  info.file = filename;
  info.waves = bse_string_seq_new ();
  if (stat (filename, &sbuf) < 0)
    info.error = bse_error_from_errno (errno, BSE_ERROR_FILE_OPEN_FAILED);
  else
    {
      info.size = sbuf.st_size;
      info.mtime = sbuf.st_mtime * SFI_USEC_FACTOR;
      wfi = gsl_wave_file_info_load (filename, &info.error);
      if (wfi)
	{
	  guint i;
	  for (i = 0; i < wfi->n_waves; i++)
	    bse_string_seq_append (info.waves, wfi->waves[i].name);
	  info.loader = (gchar*) gsl_wave_file_info_loader (wfi);
	}
    }

#line 204 "bsewaverepo.proc"
  
  bse_value_set_boxed (out_values++, &info);

#line 207 "bsewaverepo.proc"
  
  bse_string_seq_free (info.waves);
  if (wfi)
    gsl_wave_file_info_unref (wfi);

  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
static BseExportNodeProc __enode_load_file = {
  { NULL, BSE_EXPORT_NODE_PROC,
    "BseWaveRepo+load-file", 
    NULL,
    "/Methods/BseWaveRepo/General/Load File",
    "Load wave from file",
    "Tim Janik <timj@gtk.org>",
    "GNU General Public License",
  },
  0, load_file_setup, load_file_exec, 
};
static BseExportNodeProc __enode_remove_wave = {
  { (BseExportNode*) &__enode_load_file, BSE_EXPORT_NODE_PROC,
    "BseWaveRepo+remove-wave", 
    NULL,
    "/Methods/BseWaveRepo/General/Remove Wave",
    "Remove a wave from repository",
    "Tim Janik <timj@gtk.org>",
    "GNU General Public License",
  },
  0, remove_wave_setup, remove_wave_exec, 
};
static BseExportNodeProc __enode_bse_sample_file_info = {
  { (BseExportNode*) &__enode_remove_wave, BSE_EXPORT_NODE_PROC,
    "bse-sample-file-info", 
    NULL,
    "/Proc/Sample File Info",
    "Load sample file info from file",
    "Tim Janik <timj@gtk.org>",
    "GNU General Public License",
  },
  0, bse_sample_file_info_setup, bse_sample_file_info_exec, 
};
BseExportNode* bse__builtin_init_bsewaverepo_gen_proc_c (void);
BseExportNode* bse__builtin_init_bsewaverepo_gen_proc_c (void)
{
  return (BseExportNode*) &__enode_bse_sample_file_info;
}

/**
 ** Generated data ends here
 **/

==> beast_0.6.2.orig.tar.gz: beast-0.6.2/bse/bsewaverepo.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsewaverepo.proc"

#include <bse/bseplugin.h>
#include <bse/bseprocedure.h>
#include <bse/bsewaverepo.h>
#include <bse/gslloader.h>
#include <bse/bsewave.h>

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <errno.h>


#line 30 "bsewaverepo.proc"

static BseErrorType
load_file (BseWaveRepo *wrepo,
	   const gchar *file_name,
           BseWave    **wave_p)
{
  GslErrorType error;
  GslWaveFileInfo *finfo;
  GslWaveDsc *wdsc;
  BseWave *wave;
  gchar *fname;
  guint i;

  *wave_p = NULL;
  finfo = gsl_wave_file_info_load (file_name, &error);
  if (!finfo)
    return error;
  if (finfo->n_waves != 1)
    {
      gsl_wave_file_info_unref (finfo);
      return BSE_ERROR_FORMAT_UNKNOWN;
    }
  
  wdsc = gsl_wave_dsc_load (finfo, 0, &error);
  gsl_wave_file_info_unref (finfo);
  if (!wdsc)
    return error;
  
  fname = g_path_get_basename (file_name);
  wave = g_object_new (BSE_TYPE_WAVE,
		       "uname", fname,
		       NULL);
  bse_wave_set_description_bits (wave, wdsc, TRUE);
  g_free (fname);
  for (i = 0; i < wdsc->n_chunks; i++)
    {
      GslWaveChunk *wchunk = gsl_wave_chunk_create (wdsc, i, error ? NULL : &error);
      
      if (wchunk)
        bse_wave_add_chunk (wave, wchunk);
    }
  bse_wave_set_locator (wave, file_name, wdsc->name);
  
  gsl_wave_dsc_free (wdsc);
  
  if (wave->n_wchunks)
    {
      bse_container_add_item (BSE_CONTAINER (wrepo), BSE_ITEM (wave));
      *wave_p = wave;
      error = GSL_ERROR_NONE;
    }
  else
    error = BSE_ERROR_WAVE_NOT_FOUND;
  g_object_unref (wave);
  
  return error;
}


#line 89 "bsewaverepo.proc"

#line 92 "bsewaverepo.proc"


/* --- load-file --- */
static void
load_file_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 94 "bsewaverepo.proc"
 {
#line 96 "bsewaverepo.proc"
  *(in_pspecs++)    = bse_param_spec_object ("wave_repo", "Wave Repo", NULL,
				 BSE_TYPE_WAVE_REPO, SFI_PARAM_STANDARD);
  *(in_pspecs++) = sfi_pspec_string ("file_name", "File Name", "The file to import waves from",
			    NULL, SFI_PARAM_STANDARD);
  *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", NULL,
				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
				SFI_PARAM_STANDARD);
}
#line 104 "bsewaverepo.proc"
 }
static BseErrorType
#line 104 "bsewaverepo.proc"
load_file_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 107 "bsewaverepo.proc"
{
#line 108 "bsewaverepo.proc"
  
  BseWaveRepo *self    = (BseWaveRepo*) bse_value_get_object (in_values++);
  gchar *file_name     = sfi_value_get_string (in_values++);
  BseUndoStack *ustack;
  BseErrorType error;
  BseWave *wave;
  
#line 115 "bsewaverepo.proc"
  
  if (!BSE_IS_WAVE_REPO (self) || !file_name)
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  ustack = bse_item_undo_open (self, "load-wave");
  error = load_file (self, file_name, &wave);
  if (wave)
    bse_item_push_undo_proc (self, "remove-wave", wave);
  bse_item_undo_close (ustack);
  
#line 125 "bsewaverepo.proc"
  
  g_value_set_enum (out_values++, error);
  
  return BSE_ERROR_NONE;
}

/* --- remove-wave --- */
static void
remove_wave_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 131 "bsewaverepo.proc"
 {
#line 133 "bsewaverepo.proc"
  *(in_pspecs++)    = bse_param_spec_object ("wave_repo", "Wave Repo", NULL,
				 BSE_TYPE_WAVE_REPO, SFI_PARAM_STANDARD);
  *(in_pspecs++)    = bse_param_spec_object ("wave", "Wave", NULL,
				 BSE_TYPE_WAVE, SFI_PARAM_STANDARD);
#line 137 "bsewaverepo.proc"
}  }
static BseErrorType
#line 137 "bsewaverepo.proc"
remove_wave_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 140 "bsewaverepo.proc"
{
#line 141 "bsewaverepo.proc"
  
  BseWaveRepo *self = (BseWaveRepo*) bse_value_get_object (in_values++);
  BseItem *child    = (BseItem*) bse_value_get_object (in_values++);
  BseUndoStack *ustack;

#line 146 "bsewaverepo.proc"
  
  if (!BSE_IS_WAVE_REPO (self) || !BSE_IS_WAVE (child) ||
      child->parent != BSE_ITEM (self))
    return BSE_ERROR_PROC_PARAM_INVAL;
  
#line 151 "bsewaverepo.proc"
  
  ustack = bse_item_undo_open (self, "remove-wave %s", bse_object_debug_name (child));
#line 153 "bsewaverepo.proc"
  
  bse_container_uncross_undoable (BSE_CONTAINER (self), child);
#line 155 "bsewaverepo.proc"
  
  bse_item_push_redo_proc (self, "remove-wave", child);
#line 157 "bsewaverepo.proc"
  
  bse_container_remove_backedup (BSE_CONTAINER (self), child, ustack);
#line 159 "bsewaverepo.proc"
  
  bse_item_undo_close (ustack);
  
  return BSE_ERROR_NONE;
}

/* --- bse-sample-file-info --- */
static void
bse_sample_file_info_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 165 "bsewaverepo.proc"
 {
#line 167 "bsewaverepo.proc"
  *(in_pspecs++) = sfi_pspec_string ("file_name", "File Name", "The file to load info from",
			    NULL, SFI_PARAM_STANDARD);
  *(out_pspecs++)   = bse_param_spec_boxed ("sample_file_info", NULL, NULL, BSE_TYPE_SAMPLE_FILE_INFO, SFI_PARAM_STANDARD);
}
#line 171 "bsewaverepo.proc"
 }
static BseErrorType
#line 171 "bsewaverepo.proc"
bse_sample_file_info_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 174 "bsewaverepo.proc"
{
#line 175 "bsewaverepo.proc"
  
  gchar *filename = sfi_value_get_string (in_values++);
  BseSampleFileInfo info = { 0, };
  GslWaveFileInfo *wfi = NULL;
  struct stat sbuf = { 0, };

#line 181 "bsewaverepo.proc"
  
  if (!filename)
    return BSE_ERROR_PROC_PARAM_INVAL;

#line 185 "bsewaverepo.proc"
  
  info.file = filename;
  info.waves = bse_string_seq_new ();
  if (stat (filename, &sbuf) < 0)
    info.error = bse_error_from_errno (errno, BSE_ERROR_FILE_OPEN_FAILED);
  else
    {
      info.size = sbuf.st_size;
      info.mtime = sbuf.st_mtime * SFI_USEC_FACTOR;
      wfi = gsl_wave_file_info_load (filename, (GslErrorType*) &info.error);
      if (wfi)
	{
	  guint i;
	  for (i = 0; i < wfi->n_waves; i++)
	    bse_string_seq_append (info.waves, wfi->waves[i].name);
	  info.loader = (gchar*) gsl_wave_file_info_loader (wfi);
	}
    }

#line 204 "bsewaverepo.proc"
  
  bse_value_set_boxed (out_values++, &info);

#line 207 "bsewaverepo.proc"
  
  bse_string_seq_free (info.waves);
  if (wfi)
    gsl_wave_file_info_unref (wfi);

  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
static void
__enode_load_file__fill_strings (BseExportStrings *es)
{
  es->blurb = "Load wave from file";
  es->authors = "Tim Janik <timj@gtk.org>";
  es->license = "GNU General Public License";
}
static BseExportNodeProc __enode_load_file = {
  { NULL, BSE_EXPORT_NODE_PROC,
    "BseWaveRepo+load-file", 
    NULL,
    "/Methods/BseWaveRepo/General/Load File",
    NULL,
    __enode_load_file__fill_strings,
  },
  0, load_file_setup, load_file_exec, 
};
static void
__enode_remove_wave__fill_strings (BseExportStrings *es)
{
  es->blurb = "Remove a wave from repository";
  es->authors = "Tim Janik <timj@gtk.org>";
  es->license = "GNU General Public License";
}
static BseExportNodeProc __enode_remove_wave = {
  { (BseExportNode*) &__enode_load_file, BSE_EXPORT_NODE_PROC,
    "BseWaveRepo+remove-wave", 
    NULL,
    "/Methods/BseWaveRepo/General/Remove Wave",
    NULL,
    __enode_remove_wave__fill_strings,
  },
  0, remove_wave_setup, remove_wave_exec, 
};
static void
__enode_bse_sample_file_info__fill_strings (BseExportStrings *es)
{
  es->blurb = "Load sample file info from file";
  es->authors = "Tim Janik <timj@gtk.org>";
  es->license = "GNU General Public License";
}
static BseExportNodeProc __enode_bse_sample_file_info = {
  { (BseExportNode*) &__enode_remove_wave, BSE_EXPORT_NODE_PROC,
    "bse-sample-file-info", 
    NULL,
    "/Proc/Sample File Info",
    NULL,
    __enode_bse_sample_file_info__fill_strings,
  },
  0, bse_sample_file_info_setup, bse_sample_file_info_exec, 
};
BseExportNode* bse__builtin_init_bsewaverepo_gen_proc_c (void);
BseExportNode* bse__builtin_init_bsewaverepo_gen_proc_c (void)
{
  return (BseExportNode*) &__enode_bse_sample_file_info;
}

/**
 ** Generated data ends here
 **/
